<?php
// Get helper instance for web forms. This will add the opening form-tag to
// the helper's render cache which is simply a small variable in the class
// BaseHelper.
$helperInstance = ObjectFactory::createObjectByConfiguredName('web_form_helper', array($this, 'admin_user_login'));

// Formular deaktiviert?
if ($helperInstance->ifLoginIsEnabled()) {
	// Formular ist aktiv
	$helperInstance->addFormGroup('login', "Gebe hier deine Logindaten ein:");

	// Welches Loginverfahren wurde konfiguriert?
	if ($helperInstance->ifLoginWithUsername()) {
		// Login mit Username
		$helperInstance->addFormSubGroup('username', "Bitte mit deinem Nickname einloggen.");
		$helperInstance->addFieldText('username', "Dein Nickname:");
		$helperInstance->addInputTextField('username');
	} elseif ($helperInstance->ifLoginWithEmail()) {
		// Login mit Email
		$helperInstance->addFormSubGroup('email', "Bitte mit deiner Email-Adresse einloggen.");
		$helperInstance->addFieldText('email', "Deine Email-Addresse:");
		$helperInstance->addInputTextField('email');
	} else {
		// Login mit Email/Username
		$helperInstance->addFormSubGroup('user_email', "Bitte mit deinem Nickname oder Email-Adresse einloggen.");
		$helperInstance->addFieldText('user_email', "Dein Nickname/Email:");
		$helperInstance->addInputTextField('user_email');
	}

	$helperInstance->addFormSubGroup('pass', "Gebe dein Passwort von der Anmeldung ein.");
	$helperInstance->addFieldText('pass', "Dein Passwort:");
	$helperInstance->addInputPasswordField('pass');

	// CAPTCHA enabled?
	if ($helperInstance->ifFormSecuredWithCaptcha()) {
		$helperInstance->addFormGroup('captcha_user', "Das Benutzer-Login ist durch ein CAPTCHA gesch&uuml;tzt. Bitte wiederhole den angezeigten Code, damit du dich einloggen kannst.");
		$helperInstance->addCaptcha();
	} // END - if

	// Submit buttons
	$helperInstance->addFormGroup('buttons_user', "Alles richtig eingegeben?");
	$helperInstance->addInputResetButton("Formular leeren");
	$helperInstance->addInputSubmitButton("Zum {?app_full_name?} einloggen");
} else {
	// Formular deaktiviert
	$helperInstance->addFormNote('form_deactivated', "Einloggen in den <span class=\"app_name\">{?app_full_name?}</span> ist deaktiviert worden. Bitte komme sp&auml;ter noch mal wieder.");
	$helperInstance->addFormNote('admin_notice', "Nachricht vom Admin: <span id=\"disabled_reason\">".$this->getConfigInstance()->readConfig('login_disabled_reason')."</span>");
}

// Formular schliessen
$helperInstance->flushContent();

// Get helper instance
$helperInstance = ObjectFactory::createObjectByConfiguredName('web_link_helper', array($this, 'register_login_form', 'index.php?app={?app_short_name?}&amp;page=register'));

// Set link text
$helperInstance->addLinkWithTextById('register_login');

// Flush the content
$helperInstance->flushContent();

// [EOC]
?>
<div id="content_header">
	Einloggen zu <span class="app_name">{?app_full_name?}</span>
</div>

<div id="content_body">
	<div id="login_box">
		{?admin_user_login?}
	</div>
</div>

<div id="content_footer">
	Noch kein Loginaccount? {?register_login_form?}
</div>
